/*---------------------------------------------------------------------------*/
/*                                                                           */
/* FILE:    panels.c                                                         */
/*                                                                           */
/* PURPOSE: This example illustrates the relationship and use of child panels*/
/*          in LabWindows/CVI.  A child panel is a panel that is "owned" by  */
/*          another panel, its parent.                                       */
/*                                                                           */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* Include files                                                             */
/*---------------------------------------------------------------------------*/
#include <cvirte.h>  
#include <userint.h>
#include "panels.h"

/*---------------------------------------------------------------------------*/
/* Module-globals                                                            */
/*---------------------------------------------------------------------------*/
static int g_hchild1;
static int g_hchild2;
static int g_hgrandchild1;
static int g_hgrandchild2;

/*---------------------------------------------------------------------------*/
/* This is the application's entry-point.                                    */
/*---------------------------------------------------------------------------*/
int main (int argc, char *argv[])
{
    int hparent;
	int panel;
	int UIR;
	
    if (InitCVIRTE (0, argv, 0) == 0) 
        return -1;
    
    /* Load all of the panels for this sample.  Notice that we pass the      */
    /* desired parent as the first parameter to LoadPanel when loading the   */
    /* child.                                                                */
    hparent = LoadPanel (0, "panels.uir", PARENT);
	panel = LoadPanel (0, "panels.uir", panel_two); 
      
    g_hchild1 = LoadPanel (hparent, "panels.uir", CHILD1);
    g_hgrandchild1 = LoadPanel (g_hchild1, "panels.uir", GRNDCHILD1);
    g_hchild2 = LoadPanel (hparent, "panels.uir", CHILD2);
    g_hgrandchild2 = LoadPanel (g_hchild2, "panels.uir", GRNDCHILD2);

    /* Display the main parent panel (children are not automatically         */
    /* displayed) and run the UI.                                            */ 
    DisplayPanel (hparent);
    InstallPopup (panel);
	UIR = SetActiveCtrl (panel, panel_two_message);
    
    RunUserInterface();

	

    /* Free resources and return -- discarding a parent discards all children*/
    DiscardPanel (hparent);
    CloseCVIRTE ();
    return 0;
}

/*---------------------------------------------------------------------------*/
/* This callback will respond to commit events on both the Show and Hide     */
/* Command buttons.  Using the control parameter, we can detect which        */
/* actually generated the event.                                             */
/*---------------------------------------------------------------------------*/
int CVICALLBACK ShowHidePanels (int panel, int control, int event,
                                void *callbackData, int eventData1,
                                int eventData2)
{
    if (event == EVENT_COMMIT)
        {
        switch (control)
            {
            case PARENT_SHOW :
                DisplayPanel (g_hchild1);
                DisplayPanel (g_hgrandchild1);
                DisplayPanel (g_hchild2);
                DisplayPanel (g_hgrandchild2);
                break;
            case PARENT_HIDE :
                HidePanel (g_hchild1);
                HidePanel (g_hchild2);
                break;
            }
        }
    return 0;
}

/*---------------------------------------------------------------------------*/
/* Quit the UI loop.                                                         */
/*---------------------------------------------------------------------------*/
int CVICALLBACK Shutdown (int panel, int control, int event,
                          void *callbackData, int eventData1, int eventData2)
{
    if (event == EVENT_COMMIT)
        QuitUserInterface(0);
    return 0;
}

/*---------------------------------------------------------------------------*/
/* Quit the Second Panel loop.                                                         */
/*---------------------------------------------------------------------------*/
int CVICALLBACK quit (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	switch (event)
		{
		case EVENT_COMMIT:
			RemovePopup (0);

			break;
		}
	return 0;
}
